==> ihaskell-0.10.2.2-11-x86_64.pkg.tar.zst: usr/share/haskell/register/ihaskell.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ihaskell
version:              0.10.2.2
visibility:           public
id:                   ihaskell-0.10.2.2-Dh94vUYW20JKnW37pzTmno
key:                  ihaskell-0.10.2.2-Dh94vUYW20JKnW37pzTmno
license:              MIT
maintainer:           andrew.gibiansky@gmail.com
author:               Andrew Gibiansky
homepage:             http://github.com/gibiansky/IHaskell
synopsis:             A Haskell backend kernel for the IPython project.
description:
    IHaskell is a Haskell backend kernel for the IPython project. This allows using Haskell via
    a console or notebook interface. Additional packages may be installed to provide richer data visualizations.

category:             Development
abi:                  4d10cd51c62e54322c54b3fa5d024b83
exposed:              True
exposed-modules:
    IHaskell.BrokenPackages IHaskell.CSS IHaskell.Convert
    IHaskell.Convert.Args IHaskell.Convert.IpynbToLhs
    IHaskell.Convert.LhsToIpynb IHaskell.Display
    IHaskell.Eval.Completion IHaskell.Eval.Evaluate
    IHaskell.Eval.Hoogle IHaskell.Eval.Info IHaskell.Eval.Inspect
    IHaskell.Eval.Lint IHaskell.Eval.ParseShell IHaskell.Eval.Parser
    IHaskell.Eval.Util IHaskell.Eval.Widgets IHaskell.Flags
    IHaskell.IPython IHaskell.IPython.Stdin IHaskell.Publish
    IHaskell.Types IHaskellPrelude Paths_ihaskell

hidden-modules:       StringUtils
import-dirs:          /usr/lib/ghc-9.0.2/site-local/ihaskell-0.10.2.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/ihaskell-0.10.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/ihaskell
hs-libraries:         HSihaskell-0.10.2.2-Dh94vUYW20JKnW37pzTmno
depends:
    aeson-1.5.6.0-6rBoO6bU0Qo8Yma8Si89de base-4.15.1.0
    base64-bytestring-1.2.1.0-8Wzp1ohAM5521xZ4S2eRk5 binary-0.8.8.0
    bytestring-0.10.12.1 cmdargs-0.10.21-5dEStss8OK87s5amCxsPTV
    containers-0.6.4.1 directory-1.3.6.2 exceptions-0.10.4
    filepath-1.4.2.1 ghc-9.0.2 ghc-boot-9.0.2
    ghc-parser-0.2.3.0-2HLNDvFBZQWHJBvOGqm6rM
    ghc-paths-0.1.0.12-7fRPaqGgnC488dNzs2elDi haskeline-0.8.2
    hlint-3.3.6-2cq2enuwCy82hvG8Nb5CE0
    http-client-0.7.13.1-Dh7SR0m1x6o3yipHdw5yVA
    http-client-tls-0.3.6.1-1Y5QlofmlBA1SJYz2XUbk0
    ipython-kernel-0.10.2.2-Iva8Cn00Z9gCjxJf2wX8Dk parsec-3.1.14.0
    process-1.6.13.2 random-1.2.1.1-C8aN1mO2C5BFfFmB9GY7Ok
    shelly-1.10.0-HNUQkqSRNILKJkJiilw8DH
    split-0.2.3.5-DBtnzycmHvfGkfFjx30oaI stm-2.5.0.0
    strict-0.4.0.1-IhateBdKjGiCYR34MBggWG text-1.2.5.0 time-1.9.3
    transformers-0.5.6.2 unix-2.7.2.2
    unordered-containers-0.2.19.1-DKI32UXisJ5DsjnshdrAkp
    utf8-string-1.0.2-6JnEnrSpdULJYDb0wt55Uc
    vector-0.12.3.1-37YOJsTp4sSIT9CMAp9q9Q

haddock-interfaces:   /usr/share/doc/ihaskell/html/ihaskell.haddock
haddock-html:         /usr/share/doc/ihaskell/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> ihaskell-0.10.2.2-12-x86_64.pkg.tar.zst: usr/share/haskell/register/ihaskell.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ihaskell
version:              0.10.2.2
visibility:           public
id:                   ihaskell-0.10.2.2-HdMSDc8bQjxF84ThXHpGNb
key:                  ihaskell-0.10.2.2-HdMSDc8bQjxF84ThXHpGNb
license:              MIT
maintainer:           andrew.gibiansky@gmail.com
author:               Andrew Gibiansky
homepage:             http://github.com/gibiansky/IHaskell
synopsis:             A Haskell backend kernel for the IPython project.
description:
    IHaskell is a Haskell backend kernel for the IPython project. This allows using Haskell via
    a console or notebook interface. Additional packages may be installed to provide richer data visualizations.

category:             Development
abi:                  571d3630c08289ccd02c04705dc98316
exposed:              True
exposed-modules:
    IHaskell.BrokenPackages IHaskell.CSS IHaskell.Convert
    IHaskell.Convert.Args IHaskell.Convert.IpynbToLhs
    IHaskell.Convert.LhsToIpynb IHaskell.Display
    IHaskell.Eval.Completion IHaskell.Eval.Evaluate
    IHaskell.Eval.Hoogle IHaskell.Eval.Info IHaskell.Eval.Inspect
    IHaskell.Eval.Lint IHaskell.Eval.ParseShell IHaskell.Eval.Parser
    IHaskell.Eval.Util IHaskell.Eval.Widgets IHaskell.Flags
    IHaskell.IPython IHaskell.IPython.Stdin IHaskell.Publish
    IHaskell.Types IHaskellPrelude Paths_ihaskell

hidden-modules:       StringUtils
import-dirs:          /usr/lib/ghc-9.0.2/site-local/ihaskell-0.10.2.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/ihaskell-0.10.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/ihaskell
hs-libraries:         HSihaskell-0.10.2.2-HdMSDc8bQjxF84ThXHpGNb
depends:
    aeson-1.5.6.0-6rBoO6bU0Qo8Yma8Si89de base-4.15.1.0
    base64-bytestring-1.2.1.0-8Wzp1ohAM5521xZ4S2eRk5 binary-0.8.8.0
    bytestring-0.10.12.1 cmdargs-0.10.21-5dEStss8OK87s5amCxsPTV
    containers-0.6.4.1 directory-1.3.6.2 exceptions-0.10.4
    filepath-1.4.2.1 ghc-9.0.2 ghc-boot-9.0.2
    ghc-parser-0.2.3.0-2HLNDvFBZQWHJBvOGqm6rM
    ghc-paths-0.1.0.12-7fRPaqGgnC488dNzs2elDi haskeline-0.8.2
    hlint-3.3.6-8sgYy8QNZxX5bgRrjWpNQd
    http-client-0.7.13.1-Dh7SR0m1x6o3yipHdw5yVA
    http-client-tls-0.3.6.1-1Y5QlofmlBA1SJYz2XUbk0
    ipython-kernel-0.10.2.2-Iva8Cn00Z9gCjxJf2wX8Dk parsec-3.1.14.0
    process-1.6.13.2 random-1.2.1.1-C8aN1mO2C5BFfFmB9GY7Ok
    shelly-1.10.0-HNUQkqSRNILKJkJiilw8DH
    split-0.2.3.5-DBtnzycmHvfGkfFjx30oaI stm-2.5.0.0
    strict-0.4.0.1-IhateBdKjGiCYR34MBggWG text-1.2.5.0 time-1.9.3
    transformers-0.5.6.2 unix-2.7.2.2
    unordered-containers-0.2.19.1-DKI32UXisJ5DsjnshdrAkp
    utf8-string-1.0.2-6JnEnrSpdULJYDb0wt55Uc
    vector-0.12.3.1-37YOJsTp4sSIT9CMAp9q9Q

haddock-interfaces:   /usr/share/doc/ihaskell/html/ihaskell.haddock
haddock-html:         /usr/share/doc/ihaskell/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
